==> claromentis-framework-9.6.6-26891208.zip: web/intranet/people/classes/UseCase/GetUser.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array("_206592e8fa01" . "60bd42ecad148" . "e6e13e7" => base64_decode("WW91IGRvIG5vdCBoYXZl" . "IHBlcm1pc3Npb24gdG8g" . "dmlldyB0aGlzIHVzZXI="), "_1307d61617a82e798c53fada52dc" . "0114" => base64_decode("VXNlciBub" . "3QgZm91bm" . "Q="));
use Claromentis\Core\Security\Exception\AccessDeniedException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\User;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\UserRepository;




class GetUser
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repo;
    public function __construct(PeopleAcl $acl, UserRepository $repo)
    {
        $this->acl = $acl;
        $this->repo = $repo;
    }
    
    
    
    
    
    
    
    
    
    public function Get(SecurityContext $context, int $user_id, ?UserFilter $_03e9164d0a343b742df4793268b80767 = null)
    {
        if (!$_03e9164d0a343b742df4793268b80767) {
            $_03e9164d0a343b742df4793268b80767 = new UserFilter($context);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        
        
        
        
        $_24e0e36600d6af77406a44bb618a6253 = $this->repo->findOneWithFilter($user_id, $_03e9164d0a343b742df4793268b80767);
        if (empty($_24e0e36600d6af77406a44bb618a6253)) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_1307d61617a82e7" . "98c53fada52dc011" . "4"]);
        }
        if (!$this->acl->CanViewUser($context, $user_id) && !$this->acl->CanViewUserAsAdmin($context, $user_id)) {
            throw new AccessDeniedException($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_206592e8" . "fa0160bd4" . "2ecad148e" . "6e13e7"]);
        }
        return $_24e0e36600d6af77406a44bb618a6253;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/people/classes/UseCase/GetUser.php <==
<?php
namespace Claromentis\People\UseCase;

$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_206592e8fa0160bd42ecad148e6e" . "13e7" => base64_decode("WW91IGRvIG5vdCBoYXZlIHBlcm1pc3Npb24gdG8gdml" . "ldyB0aGlzIHVzZXI="), "_1307d61617a8" . "2e798c53fada5" . "2dc0114" => base64_decode("VXNlciBub3QgZm91bmQ" . "="));
use Claromentis\Core\Security\Exception\AccessDeniedException;
use Claromentis\Core\Security\SecurityContext;
use Claromentis\People\Entity\User;
use Claromentis\People\Exception\NotFoundException;
use Claromentis\People\Filter\UserFilter;
use Claromentis\People\PeopleAcl;
use Claromentis\People\Repository\UserRepository;




class GetUser
{
    
    
    
    
    protected $acl;
    
    
    
    
    protected $repo;
    public function __construct(PeopleAcl $acl, UserRepository $repo)
    {
        $this->acl = $acl;
        $this->repo = $repo;
    }
    
    
    
    
    
    
    
    
    
    public function Get(SecurityContext $context, int $user_id, ?UserFilter $_03e9164d0a343b742df4793268b80767 = null)
    {
        if (!$_03e9164d0a343b742df4793268b80767) {
            $_03e9164d0a343b742df4793268b80767 = new UserFilter($context);
        }
        $_03e9164d0a343b742df4793268b80767->SetPeopleAcl($this->acl);
        
        
        
        
        $_24e0e36600d6af77406a44bb618a6253 = $this->repo->findOneWithFilter($user_id, $_03e9164d0a343b742df4793268b80767);
        if (empty($_24e0e36600d6af77406a44bb618a6253)) {
            throw new NotFoundException($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_1307d616" . "17a82e798" . "c53fada52" . "dc0114"]);
        }
        if (!$this->acl->CanViewUser($context, $user_id) && !$this->acl->CanViewUserAsAdmin($context, $user_id)) {
            throw new AccessDeniedException($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_206592e8fa0160bd" . "42ecad148e6e13e7"]);
        }
        return $_24e0e36600d6af77406a44bb618a6253;
    }
}
